
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.20.6',
    'branch_nick': 'patch-0-Release__1_20_6_preparation',
    'revision_id': 'dc2afff13735ed86ea96a329e27424e8e04d8044',
    'revno': 8501
}
